;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "d-mode" "20241225.1823"
  "D Programming Language major mode for (X)Emacs."
  '((emacs "25.1"))
  :url "https://github.com/Emacs-D-Mode-Maintainers/Emacs-D-Mode"
  :commit "e8754635a7dbb7b1712dc9fcf380acd3ed5a2db6"
  :revdesc "e8754635a7db"
  :keywords '("d" "programming" "language" "emacs" "cc-mode")
  :maintainers '(("Russel Winder" . "russel@winder.org.uk")
                 ("Vladimir Panteleev" . "vladimir@thecybershadow.net")))
